@@ -22,7 +22,7 @@ ADTypes.AutoZygote()
 """
 Auto(package::Symbol, args...; kws...) = Auto(Val(package), args...; kws...)
 
-for backend in (:ChainRules, :Diffractor, :Enzyme, :FastDifferentiation,
+for backend in (:ChainRules, :Diffractor, :Enzyme, :Reactant, :FastDifferentiation,
     :FiniteDiff, :FiniteDifferences, :ForwardDiff, :Mooncake, :PolyesterForwardDiff,
     :ReverseDiff, :Symbolics, :Tapir, :Tracker, :Zygote)
     @eval Auto(::Val{$(QuoteNode(backend))}, args...; kws...) = $(Symbol(:Auto, backend))(
